driver-package: driver: A collection of functions for the Drives Lab at...

driver-packageR Documentation

driver: A collection of functions for the Drives Lab at Washington University

Description

A collection of functions for the Drives Lab at Washington University. Having a central location for commonly utilized code is good practice.

Author(s)

Maintainer: Matthew Schuelke matt@themadstatter.com (ORCID)

Authors:

See Also

Useful links:


DrivesLabWustl/driver documentation built on Aug. 30, 2022, 4:30 p.m.