master_crumb_template: Master Breadcrumb Template

master_crumb_templateR Documentation

Master Breadcrumb Template

Description

Daily breadcrumb formatting is inconsistent where the fields provided differ across files. Notably some contain a datetime field where the norm is to split date and time into separate fields. This tibble represents a base template to store all known breadcrumb data in a common format.

Usage

master_crumb_template

Format

An object of class tbl_df (inherits from tbl, data.frame) with 0 rows and 23 columns.


DrivesLabWustl/driver documentation built on Aug. 30, 2022, 4:30 p.m.