timestamp_filename: Append a Timestamp to the End of a File Name

View source: R/utilities.R

timestamp_filenameR Documentation

Append a Timestamp to the End of a File Name

Description

Append a Timestamp to the End of a File Name

Usage

timestamp_filename(x)

Arguments

x

file name to which a time stamp string should be appended.

Value

file name with time stamp string appended

Examples

timestamp_filename("redcap_sas_export")

DrivesLabWustl/driver documentation built on Aug. 30, 2022, 4:30 p.m.